@@ -140,9 +140,8 @@ class FemidaChecker(object):
                     status = self.pull(data['endpoint'],
                                        data['flag_id'],
                                        data['flag'])
-                    res = dict(status=status,
-                               flag=data['flag'],
-                               endpoint=data['endpoint'])
+                    res = dict(request_id=data['request_id'],
+                               status=status)
                     s = 'PULL flag {0} from {1} with flag_id {2}: result {3}'
                     self.logger.info(s.format(data['flag'],
                                               data['endpoint'],
